aboutsummaryrefslogtreecommitdiffstats
path: root/test/testthd.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/testthd.c')
-rw-r--r--test/testthd.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/testthd.c b/test/testthd.c
index 34de252a8..522e54b9b 100644
--- a/test/testthd.c
+++ b/test/testthd.c
@@ -97,11 +97,11 @@ static void thd2_execute(void) {
threads[0] = chThdCreateStatic(wa[0], WA_SIZE, chThdGetPriorityX()-5, thread, "E");
threads[4] = chThdCreateStatic(wa[4], WA_SIZE, chThdGetPriorityX()-1, thread, "A");
threads[3] = chThdCreateStatic(wa[3], WA_SIZE, chThdGetPriorityX()-2, thread, "B");
/* Done this way for coverage of chThdCreateI() and chThdResume().*/
chSysLock();
threads[2] = chThdCreateI(wa[2], WA_SIZE, chThdGetPriorityX()-3, thread, "C");
chSysUnlock();
- chThdResume(threads[2]);
+ chThdStart(threads[2]);
test_wait_threads();
test_assert_sequence(1, "ABCDE");
}
@@ -97,11 +97,11 @@ static void thd2_execute(void) {
threads[4] = chThdCreateStatic(wa[4], WA_SIZE, chThdGetPriorityX()-1, thread, "A");
threads[3] = chThdCreateStatic(wa[3], WA_SIZE, chThdGetPriorityX()-2, thread, "B");
- /* Done this way for coverage of chThdCreateI() and chThdResume().*/
+ /* Done this way for coverage of chThdCreateI() and chThdStart().*/
chSysLock();
threads[2] = chThdCreateI(wa[2], WA_SIZE, chThdGetPriorityX()-3, thread, "C");